CrosstermCanvas

Struct CrosstermCanvas 

pub struct CrosstermCanvas { /* private fields */ }
A canvas implementation that renders to the terminal using crossterm.

This canvas provides terminal-based rendering using Unicode half blocks and ANSI colors. It supports frame rate limiting and efficient updates by only redrawing changed parts of the screen.

Example

use pixel_loop::canvas::CrosstermCanvas;
use pixel_loop::color::*;
use pixel_loop::canvas::Canvas;
use pixel_loop::canvas::RenderableCanvas;
use std::ops::Range;
use anyhow::Result;

fn main() -> Result<()> {
  let mut canvas = CrosstermCanvas::new(80, 24);
  canvas.filled_rect(5, 5, 10, 10, &Color::from_rgb(255, 0, 0));
  // Should of course be called within the [pixel_loop::run] function.
  canvas.render()?;
 Ok(())
}

Implementations

Source

impl CrosstermCanvas

pub fn new() -> Self

Creates a new terminal canvas automatically toking the size of the terminal it is spawned in.

A canvas based on the terminals size is resizable by default.

Example
use pixel_loop::canvas::CrosstermCanvas;

let canvas = CrosstermCanvas::new();
pub fn new_with_size(width: u32, height: u32) -> Self

Creates a new terminal canvas with the specified dimensions.

A canvas with specified dimensions is not resizable by default.

Arguments
  • width - The width of the canvas in characters
  • height - The height of the canvas in half characters
Example
use pixel_loop::canvas::CrosstermCanvas;

let canvas = CrosstermCanvas::new(80, 42);
pub fn with_resizable(self, resizable: bool) -> Self

Sets the canvas to be resizable or not.

pub fn with_refresh_limit(self, limit: usize) -> Self

Sets the frame rate limit.

Arguments
  • limit - Target frames per second

By default, the canvas is limited to 60 frames per second.

Example
use pixel_loop::canvas::CrosstermCanvas;

// Limit the frame rate to 30 frames per second
let mut canvas = CrosstermCanvas::new(80, 24).with_refresh_limit(30);