pub struct CrosstermCanvas { /* private fields */ }Expand description
A canvas implementation that renders to the terminal using crossterm.
This canvas provides terminal-based rendering using Unicode half blocks and ANSI colors. It supports frame rate limiting and efficient updates by only redrawing changed parts of the screen.
Example
use pixel_loop::canvas::CrosstermCanvas;
use pixel_loop::color::*;
use pixel_loop::canvas::Canvas;
use pixel_loop::canvas::RenderableCanvas;
use std::ops::Range;
use anyhow::Result;
fn main() -> Result<()> {
let mut canvas = CrosstermCanvas::new(80, 24);
canvas.filled_rect(5, 5, 10, 10, &Color::from_rgb(255, 0, 0));
// Should of course be called within the [pixel_loop::run] function.
canvas.render()?;
Ok(())
}Implementations
Sourceimpl CrosstermCanvas
impl CrosstermCanvas
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new terminal canvas automatically toking the size of the terminal it is spawned in.
A canvas based on the terminals size is resizable by default.
Example
use pixel_loop::canvas::CrosstermCanvas;
let canvas = CrosstermCanvas::new();Sourcepub fn new_with_size(width: u32, height: u32) -> Self
pub fn new_with_size(width: u32, height: u32) -> Self
Creates a new terminal canvas with the specified dimensions.
A canvas with specified dimensions is not resizable by default.
Arguments
width- The width of the canvas in charactersheight- The height of the canvas in half characters
Example
use pixel_loop::canvas::CrosstermCanvas;
let canvas = CrosstermCanvas::new(80, 42);Sourcepub fn with_resizable(self, resizable: bool) -> Self
pub fn with_resizable(self, resizable: bool) -> Self
Sets the canvas to be resizable or not.
Sourcepub fn with_refresh_limit(self, limit: usize) -> Self
pub fn with_refresh_limit(self, limit: usize) -> Self